@@ -32,6 +32,8 @@ describe 'tripleo::profile::base::nova::compute' do
         )
 
         is_expected.to_not contain_class('tripleo::profile::base::nova')
+        is_expected.to_not contain_class('nova::cinder')
+        is_expected.to_not contain_class('nova::vendordata')
         is_expected.to_not contain_class('nova::compute')
         is_expected.to_not contain_class('nova::network::neutron')
       }
@@ -62,7 +64,8 @@ eos
             :keymgr_backend => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
           )
           is_expected.to contain_class('tripleo::profile::base::nova')
-          is_expected.to contain_class('tripleo::profile::base::nova')
+          is_expected.to contain_class('nova::cinder')
+          is_expected.to contain_class('nova::vendordata')
           is_expected.to contain_class('nova::compute').with(
             :keymgr_backend => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
           )
@@ -90,7 +93,8 @@ eos
         it {
           is_expected.to contain_class('tripleo::profile::base::nova::compute')
           is_expected.to contain_class('tripleo::profile::base::nova')
-          is_expected.to contain_class('tripleo::profile::base::nova')
+          is_expected.to contain_class('nova::cinder')
+          is_expected.to contain_class('nova::vendordata')
           is_expected.to contain_class('nova::compute')
           is_expected.to contain_class('nova::network::neutron')
           is_expected.to contain_package('nfs-utils')
@@ -103,7 +107,8 @@ eos
         it {
           is_expected.to contain_class('tripleo::profile::base::nova::compute')
           is_expected.to contain_class('tripleo::profile::base::nova')
-          is_expected.to contain_class('tripleo::profile::base::nova')
+          is_expected.to contain_class('nova::cinder')
+          is_expected.to contain_class('nova::vendordata')
           is_expected.to contain_class('nova::compute')
           is_expected.to contain_class('nova::network::neutron')
           is_expected.to contain_package('nfs-utils')
