@@ -24,11 +24,13 @@ describe 'tripleo::profile::base::neutron::wrappers::keepalived_state_change' do
 
   shared_examples_for 'tripleo::profile::base::neutron::wrappers::keepalived_state_change' do
 
-    context 'creates wrapper file' do
+    context 'creates wrapper file for docker' do
       let(:params) {
         {
           :keepalived_state_change_wrapper  => '/usr/local/bin/keepalived-state-change',
-          :bind_socket                      => 'unix:///run/another/docker.sock'
+          :bind_socket                      => 'unix:///run/another/docker.sock',
+          :container_cli                    => 'docker',
+          :debug                            => true,
         }
       }
 
@@ -37,10 +39,32 @@ describe 'tripleo::profile::base::neutron::wrappers::keepalived_state_change' do
           :mode   => '0755'
         )
         is_expected.to contain_file('/usr/local/bin/keepalived-state-change').with_content(
-          /ip.netns.exec.*neutron-keepalived-state-change/
+          /export DOCKER_HOST="unix:...run.another.docker.sock/
         )
         is_expected.to contain_file('/usr/local/bin/keepalived-state-change').with_content(
-          /export DOCKER_HOST="unix:...run.another.docker.sock/
+          /set -x/
+        )
+        is_expected.to contain_file('/usr/local/bin/keepalived-state-change').with_content(
+          /CMD="ip netns exec.*\/usr\/bin\/neutron-keepalived-state-change/
+        )
+      end
+    end
+
+    context 'creates wrapper file for podman' do
+      let(:params) {
+        {
+          :keepalived_state_change_wrapper  => '/usr/local/bin/keepalived-state-change',
+          :container_cli                    => 'podman',
+          :debug                            => false,
+        }
+      }
+
+      it 'should generate a wrapper file' do
+        is_expected.to contain_file('/usr/local/bin/keepalived-state-change').with(
+          :mode   => '0755'
+        )
+        is_expected.to contain_file('/usr/local/bin/keepalived-state-change').with_content(
+          /CMD='\/usr\/bin\/neutron-keepalived-state-change'/
         )
       end
     end
